@@ -4,21 +4,25 @@ import pathlib
 
 from ada.config import Settings as _Settings
 from ada.core.constants import color_map as _cmap
+from ada.visualize.renderer import MyRenderer
 
 
 class Backend:
-    def __init__(self, name, guid=None, metadata=None, units="m", parent=None, ifc_settings=None):
+    def __init__(self, name, guid=None, metadata=None, units="m", parent=None, ifc_settings=None, ifc_elem=None):
         self.name = name
         self.parent = parent
         self._ifc_settings = ifc_settings
-        from ada.core.utils import create_guid
+        from ada.ifc.utils import create_guid
 
         self.guid = create_guid() if guid is None else guid
         units = units.lower()
         if units not in _Settings.valid_units:
             raise ValueError(f'Unit type "{units}"')
         self._units = units
-        self._metadata = metadata if metadata is not None else dict()
+        self._metadata = metadata if metadata is not None else dict(props=dict())
+        self._ifc_elem = ifc_elem
+        # TODO: Currently not able to keep and edit imported ifc_elem objects
+        self._ifc_elem = None
 
     @property
     def name(self):
@@ -101,6 +105,12 @@ class Backend:
     def ifc_settings(self, value):
         self._ifc_settings = value
 
+    @property
+    def ifc_elem(self):
+        if self._ifc_elem is None:
+            self._ifc_elem = self._generate_ifc_elem()
+        return self._ifc_elem
+
     def get_assembly(self):
         """
 
@@ -121,9 +131,13 @@ class Backend:
             a += 1
             parent = parent.parent
             if a > max_levels:
+                logging.info(f"Max levels reached. {self} is highest level element")
                 break
         return parent
 
+    def _generate_ifc_elem(self):
+        raise NotImplementedError("")
+
     def remove(self):
         """
         Remove this element/part from assembly/part
@@ -132,6 +146,13 @@ class Backend:
 
         if self.parent is None:
             logging.error(f"Unable to delete {self.name} as it does not have a parent")
+            return
+
+        # if self._ifc_elem is not None:
+        #     a = self.parent.get_assembly()
+        # f = a.ifc_file
+        # This returns results in a failure error
+        # f.remove(self.ifc_elem)
 
         if type(self) is Part:
             self.parent.parts.pop(self.name)
@@ -151,16 +172,12 @@ class BackendGeom(Backend):
 
     _renderer = None
 
-    def __init__(self, name, guid=None, metadata=None, units="m", parent=None, colour=None):
-        super().__init__(name, guid, metadata, units, parent)
+    def __init__(self, name, guid=None, metadata=None, units="m", parent=None, colour=None, ifc_elem=None):
+        super().__init__(name, guid, metadata, units, parent, ifc_elem=ifc_elem)
         self._penetrations = []
         self.colour = colour
 
     def add_penetration(self, pen):
-        """
-
-        :param pen:
-        """
         from ada import Penetration, PrimBox, PrimCyl, PrimExtrude, PrimRevolve
 
         if type(pen) not in [Penetration, PrimExtrude, PrimRevolve, PrimCyl, PrimBox]:
@@ -287,8 +304,6 @@ class BackendGeom(Backend):
         else:  # Assume THREEJS
             from ipywidgets.embed import embed_minimal_html
 
-            from ada.base.renderer import MyRenderer
-
             _path = pathlib.Path("temp/index.html").resolve().absolute()
 
             renderer = MyRenderer(resolution)
@@ -305,8 +320,6 @@ class BackendGeom(Backend):
         """
         from ipywidgets.embed import embed_snippet
 
-        from ada.base.renderer import MyRenderer
-
         renderer = MyRenderer()
         renderer.DisplayObj(self)
         renderer.build_display()
@@ -351,8 +364,6 @@ class BackendGeom(Backend):
         from IPython.display import display
         from ipywidgets import HBox, VBox
 
-        from ada.base.renderer import MyRenderer
-
         renderer = MyRenderer()
 
         renderer.DisplayObj(self)
