@@ -33,7 +33,7 @@ class Settings:
     use_oriented_bbox = True  # This is only relevant if OCC bounding box is True
     make_param_elbows = False
     use_param_profiles = True
-
+    silence_display = False
     use_experimental_cache = False
 
     # IFC export settings
@@ -97,7 +97,7 @@ class User:
     def to_ifc(self):
         from datetime import datetime
 
-        from ada.core.ifc_utils import get_org, get_person
+        from ada.ifc.utils import get_org, get_person
 
         f = self.parent.ifc_file
         actor = f.create_entity("IfcActorRole", self.role.upper(), None, None)
