@@ -7,7 +7,7 @@ from itertools import chain
 
 import numpy as np
 
-from ada.core.containers import Nodes
+from ada.concepts.containers import Nodes
 from ada.core.utils import Counter, roundoff
 from ada.fem import (
     FEM,
@@ -17,7 +17,6 @@ from ada.fem import (
     Constraint,
     Csys,
     Elem,
-    ElemShapes,
     FemSection,
     FemSet,
     Interaction,
@@ -28,6 +27,7 @@ from ada.fem import (
 )
 from ada.fem.containers import FemElements, FemSections, FemSets
 from ada.fem.io.abaqus.common import AbaCards
+from ada.fem.shapes import ElemShapes
 from ada.materials.metals import CarbonSteel
 
 from ..utils import str_to_int
