@@ -1,29 +1,17 @@
 import logging
-from itertools import groupby
-from operator import attrgetter
 
 import numpy as np
 
 from ada.config import Settings as _Settings
-from ada.fem import ElemShapes, FemSection, Step
+from ada.fem import FemSection, Step
 from ada.fem.containers import FemSections
+from ada.fem.shapes import ElemShapes
 
-from ..utils import _folder_prep, get_fem_model_from_assembly
+from ..utils import get_fem_model_from_assembly
 from .common import abaqus_to_med_type
 
 
-def to_fem(
-    assembly,
-    name,
-    scratch_dir=None,
-    description=None,
-    execute=False,
-    run_ext=False,
-    cpus=2,
-    gpus=None,
-    overwrite=False,
-    exit_on_complete=True,
-):
+def to_fem(assembly, name, analysis_dir, metadata=None):
     """
     Write Code_Aster .med, .export and .comm file from Assembly data
 
@@ -32,22 +20,12 @@ def to_fem(
 
     :param assembly:
     :param name:
-    :param scratch_dir:
-    :param description:
-    :param execute:
-    :param run_ext:
-    :param cpus:
-    :param gpus:
-    :param overwrite:
-    :param exit_on_complete:
+    :param analysis_dir:
+    :param metadata:
     """
 
-    analysis_dir = _folder_prep(scratch_dir, name, overwrite)
-
-    if "info" not in assembly.metadata:
-        assembly.metadata["info"] = dict(description="")
-
-    assembly.metadata["info"]["description"] = description
+    if "info" not in metadata:
+        metadata["info"] = dict(description="")
 
     p = get_fem_model_from_assembly(assembly)
 
@@ -55,26 +33,11 @@ def to_fem(
     # for p in filter(lambda x: len(x.fem.elements) != 0, assembly.get_all_parts_in_assembly(True)):
     write_to_med(name, p, analysis_dir)
 
-    with open((analysis_dir / name).with_suffix(".export"), "w") as f:
-        f.write(write_export_file(name, cpus))
-
     with open((analysis_dir / name).with_suffix(".comm"), "w") as f:
         f.write(write_to_comm(assembly, p))
 
     print(f'Created a Code_Aster input deck at "{analysis_dir}"')
 
-    from .execute import run_code_aster
-
-    run_code_aster(
-        (analysis_dir / name).with_suffix(".export"),
-        cpus=cpus,
-        gpus=gpus,
-        run_ext=run_ext,
-        metadata=assembly.metadata,
-        execute=execute,
-        exit_on_complete=exit_on_complete,
-    )
-
 
 # COMM File input
 def write_to_comm(assembly, part):
@@ -409,7 +372,7 @@ ASSEMBLAGE(
     CHAM_MATER=material,
     CARA_ELEM=element,
     CHARGE= {bc.name}_bc,
-    NUME_DDL=CO('dofs' ),
+    NUME_DDL=CO('dofs_eig'),
     MATR_ASSE = (
         _F(MATRICE=CO('stiff'), OPTION ='RIGI_MECA',),
         _F(MATRICE=CO('mass'), OPTION ='MASS_MECA', ),
@@ -587,7 +550,7 @@ def _write_elements(part, time_step, profile, families):
 
     elements_group = time_step.create_group("MAI")
     elements_group.attrs.create("CGT", 1)
-    for group, elements in groupby(part.fem.elements, key=attrgetter("type")):
+    for group, elements in part.fem.elements.group_by_type():
         if group in ElemShapes.masses + ElemShapes.springs:
             logging.error("NotImplemented: Skipping Mass or Spring Elements")
             continue
@@ -714,7 +677,7 @@ def _add_cell_sets(cells_group, part, families):
     def get_node_ids_from_element(el_):
         return [int(n.id - 1) for n in el_.nodes]
 
-    for group, elements in groupby(part.fem.elements, key=attrgetter("type")):
+    for group, elements in part.fem.elements.group_by_type():
         if group in ElemShapes.masses + ElemShapes.springs:
             logging.error("NotImplemented: Skipping Mass or Spring Elements")
             continue
