@@ -2,7 +2,7 @@ from itertools import chain
 
 import meshio
 
-from ada.core.containers import Nodes
+from ada.concepts.containers import Nodes
 from ada.core.utils import Counter
 from ada.fem import FEM, Elem
 from ada.fem.containers import FemElements
