@@ -1,40 +1,20 @@
 import logging
 import os
-from itertools import groupby
-from operator import attrgetter
 
 import meshio
 import numpy as np
 
 from ada.config import Settings as _Settings
-from ada.fem import ElemShapes
+from ada.fem.shapes import ElemShapes
 
 
-def meshio_to_fem(
-    assembly,
-    name,
-    scratch_dir=None,
-    metadata=None,
-    execute=False,
-    run_ext=False,
-    cpus=2,
-    gpus=None,
-    overwrite=False,
-    exit_on_complete=True,
-):
+def meshio_to_fem(assembly, name, scratch_dir=None, metadata=None):
     """
 
     :param assembly:
     :param name:
     :param scratch_dir:
     :param metadata:
-    :param execute:
-    :param run_ext:
-    :param cpus:
-    :param gpus:
-    :param overwrite:
-    :param exit_on_complete:
-
     :type assembly: ada.Assembly
     :return:
     """
@@ -94,7 +74,7 @@ def fem_to_meshio(fem):
         return [int(n.id - 1) for n in el_.nodes]
 
     cells = []
-    for group, elements in groupby(fem.elements, key=attrgetter("type")):
+    for group, elements in fem.elements.group_by_type():
         if group in ElemShapes.masses + ElemShapes.springs:
             logging.error("NotImplemented: Skipping Mass or Spring Elements")
             continue
